# gsoup v0.0.5

## In a nutshell
A python library implementing various computational geometry / graphics / AR algorithms with focus on clarity rather than performance.
All the code is used for self-educational purposes and to aid with research and understanding of concepts in computational geometry / graphics.

## Long version
This library is the result of me getting tired of replicating pieces of utility code to do similar work across different projects. I decided to push any fundamental piece of code into this repository. Later on I also wanted a place I can implement any related algorithm and easily verify/test/modify them so I decided it would be usefull to add them to the same place. The focus is on clarity and concisness for all implementations, but here and there some immediate/easy performance gains are used.

## Installation
`pip install gsoup`

## Usage
`import gsoup`

## Developers
`git clone https://github.com/yoterel/gsoup.git`

`cd gsoup`

`pip install -e .`

Feel free to submit pull requests (run the tests first).
